# .DefaultApi

All URIs are relative to *https://cognitivecreditapi.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**apiConsumerProjectLocalGetCompanyComparablesSubtypes**](DefaultApi.md#apiConsumerProjectLocalGetCompanyComparablesSubtypes) | **GET** /comparables/{interval} | Get company comparables
[**apiConsumerProjectLocalGetCompanyDatapoint**](DefaultApi.md#apiConsumerProjectLocalGetCompanyDatapoint) | **GET** /datapoints/{datapointId} | Get a company datapoint
[**apiConsumerProjectLocalGetCompanyFinancials**](DefaultApi.md#apiConsumerProjectLocalGetCompanyFinancials) | **GET** /companies/{companyId}/financials | Get company financials
[**apiConsumerProjectLocalGetCompanyListings**](DefaultApi.md#apiConsumerProjectLocalGetCompanyListings) | **GET** /companies | Get company descriptions
[**apiConsumerProjectLocalGetCompanyTimeSeries**](DefaultApi.md#apiConsumerProjectLocalGetCompanyTimeSeries) | **GET** /companies/{companyId}/timeseries/{tag}/{interval} | Get company time series
[**apiConsumerProjectLocalGetComparablesUpdatesSince**](DefaultApi.md#apiConsumerProjectLocalGetComparablesUpdatesSince) | **GET** /comparables/updates | Get company comparables updates for a given time period
[**apiConsumerProjectLocalGetPeriodDates**](DefaultApi.md#apiConsumerProjectLocalGetPeriodDates) | **GET** /companies/{companyId}/periods | Get company period dates


# **apiConsumerProjectLocalGetCompanyComparablesSubtypes**
> ComparablesResponse apiConsumerProjectLocalGetCompanyComparablesSubtypes()

Returns comparables data for a list of companies for the allowed coverage_universe

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .DefaultApi(configuration);

let body:.DefaultApiApiConsumerProjectLocalGetCompanyComparablesSubtypesRequest = {
  // string | identifier for the interval of comparables data to fetch
  interval: "interval_example",
  // Date | ISO-8601 Timestamp to return comparables snapshot for (optional)
  atTimestamp: new Date('1970-01-01T00:00:00.00Z'),
  // string | filter by supplied company ids (optional)
  companyIds: "p",
  // number | maximum number of results to return - typically used when paging (optional)
  limit: 1,
  // string | identifier of last result in previous result set - allows continuation of paged results (optional)
  continuationToken: "continuation_token_example",
  // string | client supported encodings (gzip, deflate, br) (optional)
  acceptEncoding: "gzip, deflate, br",
};

apiInstance.apiConsumerProjectLocalGetCompanyComparablesSubtypes(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **interval** | [**string**] | identifier for the interval of comparables data to fetch | defaults to undefined
 **atTimestamp** | [**Date**] | ISO-8601 Timestamp to return comparables snapshot for | (optional) defaults to undefined
 **companyIds** | [**string**] | filter by supplied company ids | (optional) defaults to undefined
 **limit** | [**number**] | maximum number of results to return - typically used when paging | (optional) defaults to undefined
 **continuationToken** | [**string**] | identifier of last result in previous result set - allows continuation of paged results | (optional) defaults to undefined
 **acceptEncoding** | [**string**] | client supported encodings (gzip, deflate, br) | (optional) defaults to 'gzip, deflate, br'


### Return type

**ComparablesResponse**

### Authorization

[authorizeClient](README.md#authorizeClient)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | A list of company-comparables, each with a company id and list of comparable objects. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **apiConsumerProjectLocalGetCompanyDatapoint**
> CompanyDatapointResponse apiConsumerProjectLocalGetCompanyDatapoint()

Returns details of an individual datapoint for a company

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .DefaultApi(configuration);

let body:.DefaultApiApiConsumerProjectLocalGetCompanyDatapointRequest = {
  // string | identifier for the datapoint
  datapointId: "datapointId_example",
  // string | client supported encodings (gzip, deflate, br) (optional)
  acceptEncoding: "gzip, deflate, br",
};

apiInstance.apiConsumerProjectLocalGetCompanyDatapoint(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **datapointId** | [**string**] | identifier for the datapoint | defaults to undefined
 **acceptEncoding** | [**string**] | client supported encodings (gzip, deflate, br) | (optional) defaults to 'gzip, deflate, br'


### Return type

**CompanyDatapointResponse**

### Authorization

[authorizeClient](README.md#authorizeClient)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | A single datapoint, including details about its calculation. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **apiConsumerProjectLocalGetCompanyFinancials**
> CompanyFinancialsResponse apiConsumerProjectLocalGetCompanyFinancials()

Returns historical financials data for single company

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .DefaultApi(configuration);

let body:.DefaultApiApiConsumerProjectLocalGetCompanyFinancialsRequest = {
  // string | identifier for the company to fetch financials for
  companyId: "companyId_example",
  // Date | ISO-8601 Timestamp to return financials snapshot for (optional)
  atTimestamp: new Date('1970-01-01T00:00:00.00Z'),
  // string | client supported encodings (gzip, deflate, br) (optional)
  acceptEncoding: "gzip, deflate, br",
};

apiInstance.apiConsumerProjectLocalGetCompanyFinancials(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **companyId** | [**string**] | identifier for the company to fetch financials for | defaults to undefined
 **atTimestamp** | [**Date**] | ISO-8601 Timestamp to return financials snapshot for | (optional) defaults to undefined
 **acceptEncoding** | [**string**] | client supported encodings (gzip, deflate, br) | (optional) defaults to 'gzip, deflate, br'


### Return type

**CompanyFinancialsResponse**

### Authorization

[authorizeClient](README.md#authorizeClient)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | A list of Financials, each containing a list of historical values. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **apiConsumerProjectLocalGetCompanyListings**
> CompanyDescriptionResponse apiConsumerProjectLocalGetCompanyListings()

Returns a list of company description objects.

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .DefaultApi(configuration);

let body:.DefaultApiApiConsumerProjectLocalGetCompanyListingsRequest = {
  // Date | ISO-8601 Timestamp to return companies snapshot for (optional)
  atTimestamp: new Date('1970-01-01T00:00:00.00Z'),
  // string | filter by \'retired\' status - (true|false) (optional)
  isRetired: "is_retired_example",
  // string | filter by supplied company ids - comma separated list (optional)
  companyIds: "p",
  // string | filter by supplied company tickers (optional)
  tickers: "P",
  // number | maximum number of results to return - typically used when paging (optional)
  limit: 1,
  // Date | Only return company descriptions added or updated on or after this ISO-8601 timestamp (optional)
  updatedAfter: new Date('1970-01-01T00:00:00.00Z'),
  // Date | Only return company descriptions added or updated before this ISO-8601 timestamp (optional)
  updatedBefore: new Date('1970-01-01T00:00:00.00Z'),
  // Date | Only return company descriptions for companies with reports on or after this ISO-8601 timestamp (optional)
  lastReportedDateAfter: new Date('1970-01-01T00:00:00.00Z'),
  // Date | Only return company descriptions for companies with reports before this ISO-8601 timestamp (optional)
  lastReportedDateBefore: new Date('1970-01-01T00:00:00.00Z'),
  // string | identifier of last result in previous result set - allows continuation of paged results (optional)
  continuationToken: "continuation_token_example",
  // string | client supported encodings (gzip, deflate, br) (optional)
  acceptEncoding: "gzip, deflate, br",
};

apiInstance.apiConsumerProjectLocalGetCompanyListings(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **atTimestamp** | [**Date**] | ISO-8601 Timestamp to return companies snapshot for | (optional) defaults to undefined
 **isRetired** | [**string**] | filter by \&#39;retired\&#39; status - (true|false) | (optional) defaults to undefined
 **companyIds** | [**string**] | filter by supplied company ids - comma separated list | (optional) defaults to undefined
 **tickers** | [**string**] | filter by supplied company tickers | (optional) defaults to undefined
 **limit** | [**number**] | maximum number of results to return - typically used when paging | (optional) defaults to undefined
 **updatedAfter** | [**Date**] | Only return company descriptions added or updated on or after this ISO-8601 timestamp | (optional) defaults to undefined
 **updatedBefore** | [**Date**] | Only return company descriptions added or updated before this ISO-8601 timestamp | (optional) defaults to undefined
 **lastReportedDateAfter** | [**Date**] | Only return company descriptions for companies with reports on or after this ISO-8601 timestamp | (optional) defaults to undefined
 **lastReportedDateBefore** | [**Date**] | Only return company descriptions for companies with reports before this ISO-8601 timestamp | (optional) defaults to undefined
 **continuationToken** | [**string**] | identifier of last result in previous result set - allows continuation of paged results | (optional) defaults to undefined
 **acceptEncoding** | [**string**] | client supported encodings (gzip, deflate, br) | (optional) defaults to 'gzip, deflate, br'


### Return type

**CompanyDescriptionResponse**

### Authorization

[authorizeClient](README.md#authorizeClient)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | A list of companies, each containing company information |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **apiConsumerProjectLocalGetCompanyTimeSeries**
> CompanyTimeSeriesResponse apiConsumerProjectLocalGetCompanyTimeSeries()

Returns all historical values of a specific comparable for a given company and interval

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .DefaultApi(configuration);

let body:.DefaultApiApiConsumerProjectLocalGetCompanyTimeSeriesRequest = {
  // string | identifier for the company to fetch time series data for
  companyId: "companyId_example",
  // string | identifier for the comparable tag to fetch time series data for
  tag: "tag_example",
  // string | identifier for the interval to fetch time series data for
  interval: "interval_example",
  // string | client supported encodings (gzip, deflate, br) (optional)
  acceptEncoding: "gzip, deflate, br",
};

apiInstance.apiConsumerProjectLocalGetCompanyTimeSeries(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **companyId** | [**string**] | identifier for the company to fetch time series data for | defaults to undefined
 **tag** | [**string**] | identifier for the comparable tag to fetch time series data for | defaults to undefined
 **interval** | [**string**] | identifier for the interval to fetch time series data for | defaults to undefined
 **acceptEncoding** | [**string**] | client supported encodings (gzip, deflate, br) | (optional) defaults to 'gzip, deflate, br'


### Return type

**CompanyTimeSeriesResponse**

### Authorization

[authorizeClient](README.md#authorizeClient)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | A list of values for a particular comparable, over the reporting history of a particular company for a specific interval. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **apiConsumerProjectLocalGetComparablesUpdatesSince**
> ComparablesResponse apiConsumerProjectLocalGetComparablesUpdatesSince()

Returns comparables data for a list of companies for the allowed coverage_universe, from a given start timestamp and optional end timestamp

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .DefaultApi(configuration);

let body:.DefaultApiApiConsumerProjectLocalGetComparablesUpdatesSinceRequest = {
  // Date | ISO-8601 Timestamp to return comparables updates since (all updates greater than or equal to the timestamp) (optional)
  startTimestamp: new Date('1970-01-01T00:00:00.00Z'),
  // Date | ISO-8601 Timestamp to return comparables updates until (all updates less than, but not equal to, the timestamp) (optional)
  endTimestamp: new Date('1970-01-01T00:00:00.00Z'),
  // string | filter by supplied company ids (optional)
  companyIds: "p",
  // number | maximum number of results to return - typically used when paging (optional)
  limit: 1,
  // string | identifier of last result in previous result set - allows continuation of paged results (optional)
  continuationToken: "continuation_token_example",
  // string | client supported encodings (gzip, deflate, br) (optional)
  acceptEncoding: "gzip, deflate, br",
};

apiInstance.apiConsumerProjectLocalGetComparablesUpdatesSince(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **startTimestamp** | [**Date**] | ISO-8601 Timestamp to return comparables updates since (all updates greater than or equal to the timestamp) | (optional) defaults to undefined
 **endTimestamp** | [**Date**] | ISO-8601 Timestamp to return comparables updates until (all updates less than, but not equal to, the timestamp) | (optional) defaults to undefined
 **companyIds** | [**string**] | filter by supplied company ids | (optional) defaults to undefined
 **limit** | [**number**] | maximum number of results to return - typically used when paging | (optional) defaults to undefined
 **continuationToken** | [**string**] | identifier of last result in previous result set - allows continuation of paged results | (optional) defaults to undefined
 **acceptEncoding** | [**string**] | client supported encodings (gzip, deflate, br) | (optional) defaults to 'gzip, deflate, br'


### Return type

**ComparablesResponse**

### Authorization

[authorizeClient](README.md#authorizeClient)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | A list of company-comparables, each with a company id and list of comparable objects. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)

# **apiConsumerProjectLocalGetPeriodDates**
> CompanyPeriodDatesResponse apiConsumerProjectLocalGetPeriodDates()

Returns end dates of financial reporting periods for given company

### Example


```typescript
import {  } from '';
import * as fs from 'fs';

const configuration = .createConfiguration();
const apiInstance = new .DefaultApi(configuration);

let body:.DefaultApiApiConsumerProjectLocalGetPeriodDatesRequest = {
  // string | identifier for the company to fetch financials for
  companyId: "companyId_example",
  // string | client supported encodings (gzip, deflate, br) (optional)
  acceptEncoding: "gzip, deflate, br",
};

apiInstance.apiConsumerProjectLocalGetPeriodDates(body).then((data:any) => {
  console.log('API called successfully. Returned data: ' + data);
}).catch((error:any) => console.error(error));
```


### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **companyId** | [**string**] | identifier for the company to fetch financials for | defaults to undefined
 **acceptEncoding** | [**string**] | client supported encodings (gzip, deflate, br) | (optional) defaults to 'gzip, deflate, br'


### Return type

**CompanyPeriodDatesResponse**

### Authorization

[authorizeClient](README.md#authorizeClient)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | A list of Period Dates, each containing a financial period and its corresponding end date. |  -  |

[[Back to top]](#) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to Model list]](README.md#documentation-for-models) [[Back to README]](README.md)


