// TODO: better import syntax?
import {BaseAPIRequestFactory, RequiredError, COLLECTION_FORMATS} from './baseapi';
import {Configuration} from '../configuration';
import {RequestContext, HttpMethod, ResponseContext, HttpFile} from '../http/http';
import {ObjectSerializer} from '../models/ObjectSerializer';
import {ApiException} from './exception';
import {canConsumeForm, isCodeInRange} from '../util';
import {SecurityAuthentication} from '../auth/auth';


import { CompanyDatapointResponse } from '../models/CompanyDatapointResponse';
import { CompanyDescriptionResponse } from '../models/CompanyDescriptionResponse';
import { CompanyFinancialsResponse } from '../models/CompanyFinancialsResponse';
import { CompanyPeriodDatesResponse } from '../models/CompanyPeriodDatesResponse';
import { CompanyTimeSeriesResponse } from '../models/CompanyTimeSeriesResponse';
import { ComparablesResponse } from '../models/ComparablesResponse';

/**
 * no description
 */
export class DefaultApiRequestFactory extends BaseAPIRequestFactory {

    /**
     * Returns comparables data for a list of companies for the allowed coverage_universe
     * Get company comparables
     * @param interval identifier for the interval of comparables data to fetch
     * @param atTimestamp ISO-8601 Timestamp to return comparables snapshot for
     * @param companyIds filter by supplied company ids
     * @param limit maximum number of results to return - typically used when paging
     * @param continuationToken identifier of last result in previous result set - allows continuation of paged results
     * @param acceptEncoding client supported encodings (gzip, deflate, br)
     */
    public async apiConsumerProjectLocalGetCompanyComparablesSubtypes(interval: string, atTimestamp?: Date, companyIds?: string, limit?: number, continuationToken?: string, acceptEncoding?: string, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'interval' is not null or undefined
        if (interval === null || interval === undefined) {
            throw new RequiredError("DefaultApi", "apiConsumerProjectLocalGetCompanyComparablesSubtypes", "interval");
        }







        // Path Params
        const localVarPath = '/comparables/{interval}'
            .replace('{' + 'interval' + '}', encodeURIComponent(String(interval)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Query Params
        if (atTimestamp !== undefined) {
            requestContext.setQueryParam("at_timestamp", ObjectSerializer.serialize(atTimestamp, "Date", "date-time"));
        }

        // Query Params
        if (companyIds !== undefined) {
            requestContext.setQueryParam("company_ids", ObjectSerializer.serialize(companyIds, "string", ""));
        }

        // Query Params
        if (limit !== undefined) {
            requestContext.setQueryParam("limit", ObjectSerializer.serialize(limit, "number", ""));
        }

        // Query Params
        if (continuationToken !== undefined) {
            requestContext.setQueryParam("continuation_token", ObjectSerializer.serialize(continuationToken, "string", ""));
        }

        // Header Params
        requestContext.setHeaderParam("Accept-Encoding", ObjectSerializer.serialize(acceptEncoding, "string", ""));


        let authMethod: SecurityAuthentication | undefined;
        // Apply auth methods
        authMethod = _config.authMethods["authorizeClient"]
        if (authMethod?.applySecurityAuthentication) {
            await authMethod?.applySecurityAuthentication(requestContext);
        }
        
        const defaultAuth: SecurityAuthentication | undefined = _options?.authMethods?.default || this.configuration?.authMethods?.default
        if (defaultAuth?.applySecurityAuthentication) {
            await defaultAuth?.applySecurityAuthentication(requestContext);
        }

        return requestContext;
    }

    /**
     * Returns details of an individual datapoint for a company
     * Get a company datapoint
     * @param datapointId identifier for the datapoint
     * @param acceptEncoding client supported encodings (gzip, deflate, br)
     */
    public async apiConsumerProjectLocalGetCompanyDatapoint(datapointId: string, acceptEncoding?: string, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'datapointId' is not null or undefined
        if (datapointId === null || datapointId === undefined) {
            throw new RequiredError("DefaultApi", "apiConsumerProjectLocalGetCompanyDatapoint", "datapointId");
        }



        // Path Params
        const localVarPath = '/datapoints/{datapointId}'
            .replace('{' + 'datapointId' + '}', encodeURIComponent(String(datapointId)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Header Params
        requestContext.setHeaderParam("Accept-Encoding", ObjectSerializer.serialize(acceptEncoding, "string", ""));


        let authMethod: SecurityAuthentication | undefined;
        // Apply auth methods
        authMethod = _config.authMethods["authorizeClient"]
        if (authMethod?.applySecurityAuthentication) {
            await authMethod?.applySecurityAuthentication(requestContext);
        }
        
        const defaultAuth: SecurityAuthentication | undefined = _options?.authMethods?.default || this.configuration?.authMethods?.default
        if (defaultAuth?.applySecurityAuthentication) {
            await defaultAuth?.applySecurityAuthentication(requestContext);
        }

        return requestContext;
    }

    /**
     * Returns historical financials data for single company
     * Get company financials
     * @param companyId identifier for the company to fetch financials for
     * @param atTimestamp ISO-8601 Timestamp to return financials snapshot for
     * @param acceptEncoding client supported encodings (gzip, deflate, br)
     */
    public async apiConsumerProjectLocalGetCompanyFinancials(companyId: string, atTimestamp?: Date, acceptEncoding?: string, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'companyId' is not null or undefined
        if (companyId === null || companyId === undefined) {
            throw new RequiredError("DefaultApi", "apiConsumerProjectLocalGetCompanyFinancials", "companyId");
        }




        // Path Params
        const localVarPath = '/companies/{companyId}/financials'
            .replace('{' + 'companyId' + '}', encodeURIComponent(String(companyId)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Query Params
        if (atTimestamp !== undefined) {
            requestContext.setQueryParam("at_timestamp", ObjectSerializer.serialize(atTimestamp, "Date", "date-time"));
        }

        // Header Params
        requestContext.setHeaderParam("Accept-Encoding", ObjectSerializer.serialize(acceptEncoding, "string", ""));


        let authMethod: SecurityAuthentication | undefined;
        // Apply auth methods
        authMethod = _config.authMethods["authorizeClient"]
        if (authMethod?.applySecurityAuthentication) {
            await authMethod?.applySecurityAuthentication(requestContext);
        }
        
        const defaultAuth: SecurityAuthentication | undefined = _options?.authMethods?.default || this.configuration?.authMethods?.default
        if (defaultAuth?.applySecurityAuthentication) {
            await defaultAuth?.applySecurityAuthentication(requestContext);
        }

        return requestContext;
    }

    /**
     * Returns a list of company description objects.
     * Get company descriptions
     * @param atTimestamp ISO-8601 Timestamp to return companies snapshot for
     * @param isRetired filter by \&#39;retired\&#39; status - (true|false)
     * @param companyIds filter by supplied company ids - comma separated list
     * @param tickers filter by supplied company tickers
     * @param limit maximum number of results to return - typically used when paging
     * @param updatedAfter Only return company descriptions added or updated on or after this ISO-8601 timestamp
     * @param updatedBefore Only return company descriptions added or updated before this ISO-8601 timestamp
     * @param lastReportedDateAfter Only return company descriptions for companies with reports on or after this ISO-8601 timestamp
     * @param lastReportedDateBefore Only return company descriptions for companies with reports before this ISO-8601 timestamp
     * @param continuationToken identifier of last result in previous result set - allows continuation of paged results
     * @param acceptEncoding client supported encodings (gzip, deflate, br)
     */
    public async apiConsumerProjectLocalGetCompanyListings(atTimestamp?: Date, isRetired?: string, companyIds?: string, tickers?: string, limit?: number, updatedAfter?: Date, updatedBefore?: Date, lastReportedDateAfter?: Date, lastReportedDateBefore?: Date, continuationToken?: string, acceptEncoding?: string, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;












        // Path Params
        const localVarPath = '/companies';

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Query Params
        if (atTimestamp !== undefined) {
            requestContext.setQueryParam("at_timestamp", ObjectSerializer.serialize(atTimestamp, "Date", "date-time"));
        }

        // Query Params
        if (isRetired !== undefined) {
            requestContext.setQueryParam("is_retired", ObjectSerializer.serialize(isRetired, "string", ""));
        }

        // Query Params
        if (companyIds !== undefined) {
            requestContext.setQueryParam("company_ids", ObjectSerializer.serialize(companyIds, "string", ""));
        }

        // Query Params
        if (tickers !== undefined) {
            requestContext.setQueryParam("tickers", ObjectSerializer.serialize(tickers, "string", ""));
        }

        // Query Params
        if (limit !== undefined) {
            requestContext.setQueryParam("limit", ObjectSerializer.serialize(limit, "number", ""));
        }

        // Query Params
        if (updatedAfter !== undefined) {
            requestContext.setQueryParam("updated_after", ObjectSerializer.serialize(updatedAfter, "Date", "date-time"));
        }

        // Query Params
        if (updatedBefore !== undefined) {
            requestContext.setQueryParam("updated_before", ObjectSerializer.serialize(updatedBefore, "Date", "date-time"));
        }

        // Query Params
        if (lastReportedDateAfter !== undefined) {
            requestContext.setQueryParam("last_reported_date_after", ObjectSerializer.serialize(lastReportedDateAfter, "Date", "date-time"));
        }

        // Query Params
        if (lastReportedDateBefore !== undefined) {
            requestContext.setQueryParam("last_reported_date_before", ObjectSerializer.serialize(lastReportedDateBefore, "Date", "date-time"));
        }

        // Query Params
        if (continuationToken !== undefined) {
            requestContext.setQueryParam("continuation_token", ObjectSerializer.serialize(continuationToken, "string", ""));
        }

        // Header Params
        requestContext.setHeaderParam("Accept-Encoding", ObjectSerializer.serialize(acceptEncoding, "string", ""));


        let authMethod: SecurityAuthentication | undefined;
        // Apply auth methods
        authMethod = _config.authMethods["authorizeClient"]
        if (authMethod?.applySecurityAuthentication) {
            await authMethod?.applySecurityAuthentication(requestContext);
        }
        
        const defaultAuth: SecurityAuthentication | undefined = _options?.authMethods?.default || this.configuration?.authMethods?.default
        if (defaultAuth?.applySecurityAuthentication) {
            await defaultAuth?.applySecurityAuthentication(requestContext);
        }

        return requestContext;
    }

    /**
     * Returns all historical values of a specific comparable for a given company and interval
     * Get company time series
     * @param companyId identifier for the company to fetch time series data for
     * @param tag identifier for the comparable tag to fetch time series data for
     * @param interval identifier for the interval to fetch time series data for
     * @param acceptEncoding client supported encodings (gzip, deflate, br)
     */
    public async apiConsumerProjectLocalGetCompanyTimeSeries(companyId: string, tag: string, interval: string, acceptEncoding?: string, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'companyId' is not null or undefined
        if (companyId === null || companyId === undefined) {
            throw new RequiredError("DefaultApi", "apiConsumerProjectLocalGetCompanyTimeSeries", "companyId");
        }


        // verify required parameter 'tag' is not null or undefined
        if (tag === null || tag === undefined) {
            throw new RequiredError("DefaultApi", "apiConsumerProjectLocalGetCompanyTimeSeries", "tag");
        }


        // verify required parameter 'interval' is not null or undefined
        if (interval === null || interval === undefined) {
            throw new RequiredError("DefaultApi", "apiConsumerProjectLocalGetCompanyTimeSeries", "interval");
        }



        // Path Params
        const localVarPath = '/companies/{companyId}/timeseries/{tag}/{interval}'
            .replace('{' + 'companyId' + '}', encodeURIComponent(String(companyId)))
            .replace('{' + 'tag' + '}', encodeURIComponent(String(tag)))
            .replace('{' + 'interval' + '}', encodeURIComponent(String(interval)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Header Params
        requestContext.setHeaderParam("Accept-Encoding", ObjectSerializer.serialize(acceptEncoding, "string", ""));


        let authMethod: SecurityAuthentication | undefined;
        // Apply auth methods
        authMethod = _config.authMethods["authorizeClient"]
        if (authMethod?.applySecurityAuthentication) {
            await authMethod?.applySecurityAuthentication(requestContext);
        }
        
        const defaultAuth: SecurityAuthentication | undefined = _options?.authMethods?.default || this.configuration?.authMethods?.default
        if (defaultAuth?.applySecurityAuthentication) {
            await defaultAuth?.applySecurityAuthentication(requestContext);
        }

        return requestContext;
    }

    /**
     * Returns comparables data for a list of companies for the allowed coverage_universe, from a given start timestamp and optional end timestamp
     * Get company comparables updates for a given time period
     * @param startTimestamp ISO-8601 Timestamp to return comparables updates since (all updates greater than or equal to the timestamp)
     * @param endTimestamp ISO-8601 Timestamp to return comparables updates until (all updates less than, but not equal to, the timestamp)
     * @param companyIds filter by supplied company ids
     * @param limit maximum number of results to return - typically used when paging
     * @param continuationToken identifier of last result in previous result set - allows continuation of paged results
     * @param acceptEncoding client supported encodings (gzip, deflate, br)
     */
    public async apiConsumerProjectLocalGetComparablesUpdatesSince(startTimestamp?: Date, endTimestamp?: Date, companyIds?: string, limit?: number, continuationToken?: string, acceptEncoding?: string, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;







        // Path Params
        const localVarPath = '/comparables/updates';

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Query Params
        if (startTimestamp !== undefined) {
            requestContext.setQueryParam("start_timestamp", ObjectSerializer.serialize(startTimestamp, "Date", "date-time"));
        }

        // Query Params
        if (endTimestamp !== undefined) {
            requestContext.setQueryParam("end_timestamp", ObjectSerializer.serialize(endTimestamp, "Date", "date-time"));
        }

        // Query Params
        if (companyIds !== undefined) {
            requestContext.setQueryParam("company_ids", ObjectSerializer.serialize(companyIds, "string", ""));
        }

        // Query Params
        if (limit !== undefined) {
            requestContext.setQueryParam("limit", ObjectSerializer.serialize(limit, "number", ""));
        }

        // Query Params
        if (continuationToken !== undefined) {
            requestContext.setQueryParam("continuation_token", ObjectSerializer.serialize(continuationToken, "string", ""));
        }

        // Header Params
        requestContext.setHeaderParam("Accept-Encoding", ObjectSerializer.serialize(acceptEncoding, "string", ""));


        let authMethod: SecurityAuthentication | undefined;
        // Apply auth methods
        authMethod = _config.authMethods["authorizeClient"]
        if (authMethod?.applySecurityAuthentication) {
            await authMethod?.applySecurityAuthentication(requestContext);
        }
        
        const defaultAuth: SecurityAuthentication | undefined = _options?.authMethods?.default || this.configuration?.authMethods?.default
        if (defaultAuth?.applySecurityAuthentication) {
            await defaultAuth?.applySecurityAuthentication(requestContext);
        }

        return requestContext;
    }

    /**
     * Returns end dates of financial reporting periods for given company
     * Get company period dates
     * @param companyId identifier for the company to fetch financials for
     * @param acceptEncoding client supported encodings (gzip, deflate, br)
     */
    public async apiConsumerProjectLocalGetPeriodDates(companyId: string, acceptEncoding?: string, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'companyId' is not null or undefined
        if (companyId === null || companyId === undefined) {
            throw new RequiredError("DefaultApi", "apiConsumerProjectLocalGetPeriodDates", "companyId");
        }



        // Path Params
        const localVarPath = '/companies/{companyId}/periods'
            .replace('{' + 'companyId' + '}', encodeURIComponent(String(companyId)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Header Params
        requestContext.setHeaderParam("Accept-Encoding", ObjectSerializer.serialize(acceptEncoding, "string", ""));


        let authMethod: SecurityAuthentication | undefined;
        // Apply auth methods
        authMethod = _config.authMethods["authorizeClient"]
        if (authMethod?.applySecurityAuthentication) {
            await authMethod?.applySecurityAuthentication(requestContext);
        }
        
        const defaultAuth: SecurityAuthentication | undefined = _options?.authMethods?.default || this.configuration?.authMethods?.default
        if (defaultAuth?.applySecurityAuthentication) {
            await defaultAuth?.applySecurityAuthentication(requestContext);
        }

        return requestContext;
    }

}

export class DefaultApiResponseProcessor {

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to apiConsumerProjectLocalGetCompanyComparablesSubtypes
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async apiConsumerProjectLocalGetCompanyComparablesSubtypes(response: ResponseContext): Promise<ComparablesResponse > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: ComparablesResponse = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "ComparablesResponse", ""
            ) as ComparablesResponse;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: ComparablesResponse = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "ComparablesResponse", ""
            ) as ComparablesResponse;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to apiConsumerProjectLocalGetCompanyDatapoint
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async apiConsumerProjectLocalGetCompanyDatapoint(response: ResponseContext): Promise<CompanyDatapointResponse > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: CompanyDatapointResponse = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "CompanyDatapointResponse", ""
            ) as CompanyDatapointResponse;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: CompanyDatapointResponse = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "CompanyDatapointResponse", ""
            ) as CompanyDatapointResponse;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to apiConsumerProjectLocalGetCompanyFinancials
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async apiConsumerProjectLocalGetCompanyFinancials(response: ResponseContext): Promise<CompanyFinancialsResponse > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: CompanyFinancialsResponse = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "CompanyFinancialsResponse", ""
            ) as CompanyFinancialsResponse;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: CompanyFinancialsResponse = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "CompanyFinancialsResponse", ""
            ) as CompanyFinancialsResponse;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to apiConsumerProjectLocalGetCompanyListings
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async apiConsumerProjectLocalGetCompanyListings(response: ResponseContext): Promise<CompanyDescriptionResponse > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: CompanyDescriptionResponse = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "CompanyDescriptionResponse", ""
            ) as CompanyDescriptionResponse;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: CompanyDescriptionResponse = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "CompanyDescriptionResponse", ""
            ) as CompanyDescriptionResponse;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to apiConsumerProjectLocalGetCompanyTimeSeries
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async apiConsumerProjectLocalGetCompanyTimeSeries(response: ResponseContext): Promise<CompanyTimeSeriesResponse > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: CompanyTimeSeriesResponse = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "CompanyTimeSeriesResponse", ""
            ) as CompanyTimeSeriesResponse;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: CompanyTimeSeriesResponse = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "CompanyTimeSeriesResponse", ""
            ) as CompanyTimeSeriesResponse;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to apiConsumerProjectLocalGetComparablesUpdatesSince
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async apiConsumerProjectLocalGetComparablesUpdatesSince(response: ResponseContext): Promise<ComparablesResponse > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: ComparablesResponse = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "ComparablesResponse", ""
            ) as ComparablesResponse;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: ComparablesResponse = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "ComparablesResponse", ""
            ) as ComparablesResponse;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to apiConsumerProjectLocalGetPeriodDates
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async apiConsumerProjectLocalGetPeriodDates(response: ResponseContext): Promise<CompanyPeriodDatesResponse > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: CompanyPeriodDatesResponse = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "CompanyPeriodDatesResponse", ""
            ) as CompanyPeriodDatesResponse;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: CompanyPeriodDatesResponse = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "CompanyPeriodDatesResponse", ""
            ) as CompanyPeriodDatesResponse;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

}
