import { ResponseContext, RequestContext, HttpFile } from '../http/http';
import { Configuration} from '../configuration'

import { CommentRefsInner } from '../models/CommentRefsInner';
import { CompanyDatapointResponse } from '../models/CompanyDatapointResponse';
import { CompanyDatapointResponseData } from '../models/CompanyDatapointResponseData';
import { CompanyDescriptionResponse } from '../models/CompanyDescriptionResponse';
import { CompanyDescriptionResponseMeta } from '../models/CompanyDescriptionResponseMeta';
import { CompanyFinancialsResponse } from '../models/CompanyFinancialsResponse';
import { CompanyFinancialsResponseData } from '../models/CompanyFinancialsResponseData';
import { CompanyPeriodDatesResponse } from '../models/CompanyPeriodDatesResponse';
import { CompanyPeriodDatesResponseData } from '../models/CompanyPeriodDatesResponseData';
import { CompanyTimeSeriesResponse } from '../models/CompanyTimeSeriesResponse';
import { CompanyTimeSeriesResponseData } from '../models/CompanyTimeSeriesResponseData';
import { ComparablesInner } from '../models/ComparablesInner';
import { ComparablesResponse } from '../models/ComparablesResponse';
import { DataInner } from '../models/DataInner';
import { DataInner1 } from '../models/DataInner1';
import { DataInner2 } from '../models/DataInner2';
import { FinancialsInner } from '../models/FinancialsInner';
import { Multiplier } from '../models/Multiplier';
import { PartsInner } from '../models/PartsInner';
import { PeriodDatesInner } from '../models/PeriodDatesInner';
import { TimeSeriesInner } from '../models/TimeSeriesInner';

import { ObservableDefaultApi } from "./ObservableAPI";
import { DefaultApiRequestFactory, DefaultApiResponseProcessor} from "../apis/DefaultApi";

export interface DefaultApiApiConsumerProjectLocalGetCompanyComparablesSubtypesRequest {
    /**
     * identifier for the interval of comparables data to fetch
     * @type string
     * @memberof DefaultApiapiConsumerProjectLocalGetCompanyComparablesSubtypes
     */
    interval: string
    /**
     * ISO-8601 Timestamp to return comparables snapshot for
     * @type Date
     * @memberof DefaultApiapiConsumerProjectLocalGetCompanyComparablesSubtypes
     */
    atTimestamp?: Date
    /**
     * filter by supplied company ids
     * @type string
     * @memberof DefaultApiapiConsumerProjectLocalGetCompanyComparablesSubtypes
     */
    companyIds?: string
    /**
     * maximum number of results to return - typically used when paging
     * @type number
     * @memberof DefaultApiapiConsumerProjectLocalGetCompanyComparablesSubtypes
     */
    limit?: number
    /**
     * identifier of last result in previous result set - allows continuation of paged results
     * @type string
     * @memberof DefaultApiapiConsumerProjectLocalGetCompanyComparablesSubtypes
     */
    continuationToken?: string
    /**
     * client supported encodings (gzip, deflate, br)
     * @type string
     * @memberof DefaultApiapiConsumerProjectLocalGetCompanyComparablesSubtypes
     */
    acceptEncoding?: string
}

export interface DefaultApiApiConsumerProjectLocalGetCompanyDatapointRequest {
    /**
     * identifier for the datapoint
     * @type string
     * @memberof DefaultApiapiConsumerProjectLocalGetCompanyDatapoint
     */
    datapointId: string
    /**
     * client supported encodings (gzip, deflate, br)
     * @type string
     * @memberof DefaultApiapiConsumerProjectLocalGetCompanyDatapoint
     */
    acceptEncoding?: string
}

export interface DefaultApiApiConsumerProjectLocalGetCompanyFinancialsRequest {
    /**
     * identifier for the company to fetch financials for
     * @type string
     * @memberof DefaultApiapiConsumerProjectLocalGetCompanyFinancials
     */
    companyId: string
    /**
     * ISO-8601 Timestamp to return financials snapshot for
     * @type Date
     * @memberof DefaultApiapiConsumerProjectLocalGetCompanyFinancials
     */
    atTimestamp?: Date
    /**
     * client supported encodings (gzip, deflate, br)
     * @type string
     * @memberof DefaultApiapiConsumerProjectLocalGetCompanyFinancials
     */
    acceptEncoding?: string
}

export interface DefaultApiApiConsumerProjectLocalGetCompanyListingsRequest {
    /**
     * ISO-8601 Timestamp to return companies snapshot for
     * @type Date
     * @memberof DefaultApiapiConsumerProjectLocalGetCompanyListings
     */
    atTimestamp?: Date
    /**
     * filter by \&#39;retired\&#39; status - (true|false)
     * @type string
     * @memberof DefaultApiapiConsumerProjectLocalGetCompanyListings
     */
    isRetired?: string
    /**
     * filter by supplied company ids - comma separated list
     * @type string
     * @memberof DefaultApiapiConsumerProjectLocalGetCompanyListings
     */
    companyIds?: string
    /**
     * filter by supplied company tickers
     * @type string
     * @memberof DefaultApiapiConsumerProjectLocalGetCompanyListings
     */
    tickers?: string
    /**
     * maximum number of results to return - typically used when paging
     * @type number
     * @memberof DefaultApiapiConsumerProjectLocalGetCompanyListings
     */
    limit?: number
    /**
     * Only return company descriptions added or updated on or after this ISO-8601 timestamp
     * @type Date
     * @memberof DefaultApiapiConsumerProjectLocalGetCompanyListings
     */
    updatedAfter?: Date
    /**
     * Only return company descriptions added or updated before this ISO-8601 timestamp
     * @type Date
     * @memberof DefaultApiapiConsumerProjectLocalGetCompanyListings
     */
    updatedBefore?: Date
    /**
     * Only return company descriptions for companies with reports on or after this ISO-8601 timestamp
     * @type Date
     * @memberof DefaultApiapiConsumerProjectLocalGetCompanyListings
     */
    lastReportedDateAfter?: Date
    /**
     * Only return company descriptions for companies with reports before this ISO-8601 timestamp
     * @type Date
     * @memberof DefaultApiapiConsumerProjectLocalGetCompanyListings
     */
    lastReportedDateBefore?: Date
    /**
     * identifier of last result in previous result set - allows continuation of paged results
     * @type string
     * @memberof DefaultApiapiConsumerProjectLocalGetCompanyListings
     */
    continuationToken?: string
    /**
     * client supported encodings (gzip, deflate, br)
     * @type string
     * @memberof DefaultApiapiConsumerProjectLocalGetCompanyListings
     */
    acceptEncoding?: string
}

export interface DefaultApiApiConsumerProjectLocalGetCompanyTimeSeriesRequest {
    /**
     * identifier for the company to fetch time series data for
     * @type string
     * @memberof DefaultApiapiConsumerProjectLocalGetCompanyTimeSeries
     */
    companyId: string
    /**
     * identifier for the comparable tag to fetch time series data for
     * @type string
     * @memberof DefaultApiapiConsumerProjectLocalGetCompanyTimeSeries
     */
    tag: string
    /**
     * identifier for the interval to fetch time series data for
     * @type string
     * @memberof DefaultApiapiConsumerProjectLocalGetCompanyTimeSeries
     */
    interval: string
    /**
     * client supported encodings (gzip, deflate, br)
     * @type string
     * @memberof DefaultApiapiConsumerProjectLocalGetCompanyTimeSeries
     */
    acceptEncoding?: string
}

export interface DefaultApiApiConsumerProjectLocalGetComparablesUpdatesSinceRequest {
    /**
     * ISO-8601 Timestamp to return comparables updates since (all updates greater than or equal to the timestamp)
     * @type Date
     * @memberof DefaultApiapiConsumerProjectLocalGetComparablesUpdatesSince
     */
    startTimestamp?: Date
    /**
     * ISO-8601 Timestamp to return comparables updates until (all updates less than, but not equal to, the timestamp)
     * @type Date
     * @memberof DefaultApiapiConsumerProjectLocalGetComparablesUpdatesSince
     */
    endTimestamp?: Date
    /**
     * filter by supplied company ids
     * @type string
     * @memberof DefaultApiapiConsumerProjectLocalGetComparablesUpdatesSince
     */
    companyIds?: string
    /**
     * maximum number of results to return - typically used when paging
     * @type number
     * @memberof DefaultApiapiConsumerProjectLocalGetComparablesUpdatesSince
     */
    limit?: number
    /**
     * identifier of last result in previous result set - allows continuation of paged results
     * @type string
     * @memberof DefaultApiapiConsumerProjectLocalGetComparablesUpdatesSince
     */
    continuationToken?: string
    /**
     * client supported encodings (gzip, deflate, br)
     * @type string
     * @memberof DefaultApiapiConsumerProjectLocalGetComparablesUpdatesSince
     */
    acceptEncoding?: string
}

export interface DefaultApiApiConsumerProjectLocalGetPeriodDatesRequest {
    /**
     * identifier for the company to fetch financials for
     * @type string
     * @memberof DefaultApiapiConsumerProjectLocalGetPeriodDates
     */
    companyId: string
    /**
     * client supported encodings (gzip, deflate, br)
     * @type string
     * @memberof DefaultApiapiConsumerProjectLocalGetPeriodDates
     */
    acceptEncoding?: string
}

export class ObjectDefaultApi {
    private api: ObservableDefaultApi

    public constructor(configuration: Configuration, requestFactory?: DefaultApiRequestFactory, responseProcessor?: DefaultApiResponseProcessor) {
        this.api = new ObservableDefaultApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Returns comparables data for a list of companies for the allowed coverage_universe
     * Get company comparables
     * @param param the request object
     */
    public apiConsumerProjectLocalGetCompanyComparablesSubtypes(param: DefaultApiApiConsumerProjectLocalGetCompanyComparablesSubtypesRequest, options?: Configuration): Promise<ComparablesResponse> {
        return this.api.apiConsumerProjectLocalGetCompanyComparablesSubtypes(param.interval, param.atTimestamp, param.companyIds, param.limit, param.continuationToken, param.acceptEncoding,  options).toPromise();
    }

    /**
     * Returns details of an individual datapoint for a company
     * Get a company datapoint
     * @param param the request object
     */
    public apiConsumerProjectLocalGetCompanyDatapoint(param: DefaultApiApiConsumerProjectLocalGetCompanyDatapointRequest, options?: Configuration): Promise<CompanyDatapointResponse> {
        return this.api.apiConsumerProjectLocalGetCompanyDatapoint(param.datapointId, param.acceptEncoding,  options).toPromise();
    }

    /**
     * Returns historical financials data for single company
     * Get company financials
     * @param param the request object
     */
    public apiConsumerProjectLocalGetCompanyFinancials(param: DefaultApiApiConsumerProjectLocalGetCompanyFinancialsRequest, options?: Configuration): Promise<CompanyFinancialsResponse> {
        return this.api.apiConsumerProjectLocalGetCompanyFinancials(param.companyId, param.atTimestamp, param.acceptEncoding,  options).toPromise();
    }

    /**
     * Returns a list of company description objects.
     * Get company descriptions
     * @param param the request object
     */
    public apiConsumerProjectLocalGetCompanyListings(param: DefaultApiApiConsumerProjectLocalGetCompanyListingsRequest = {}, options?: Configuration): Promise<CompanyDescriptionResponse> {
        return this.api.apiConsumerProjectLocalGetCompanyListings(param.atTimestamp, param.isRetired, param.companyIds, param.tickers, param.limit, param.updatedAfter, param.updatedBefore, param.lastReportedDateAfter, param.lastReportedDateBefore, param.continuationToken, param.acceptEncoding,  options).toPromise();
    }

    /**
     * Returns all historical values of a specific comparable for a given company and interval
     * Get company time series
     * @param param the request object
     */
    public apiConsumerProjectLocalGetCompanyTimeSeries(param: DefaultApiApiConsumerProjectLocalGetCompanyTimeSeriesRequest, options?: Configuration): Promise<CompanyTimeSeriesResponse> {
        return this.api.apiConsumerProjectLocalGetCompanyTimeSeries(param.companyId, param.tag, param.interval, param.acceptEncoding,  options).toPromise();
    }

    /**
     * Returns comparables data for a list of companies for the allowed coverage_universe, from a given start timestamp and optional end timestamp
     * Get company comparables updates for a given time period
     * @param param the request object
     */
    public apiConsumerProjectLocalGetComparablesUpdatesSince(param: DefaultApiApiConsumerProjectLocalGetComparablesUpdatesSinceRequest = {}, options?: Configuration): Promise<ComparablesResponse> {
        return this.api.apiConsumerProjectLocalGetComparablesUpdatesSince(param.startTimestamp, param.endTimestamp, param.companyIds, param.limit, param.continuationToken, param.acceptEncoding,  options).toPromise();
    }

    /**
     * Returns end dates of financial reporting periods for given company
     * Get company period dates
     * @param param the request object
     */
    public apiConsumerProjectLocalGetPeriodDates(param: DefaultApiApiConsumerProjectLocalGetPeriodDatesRequest, options?: Configuration): Promise<CompanyPeriodDatesResponse> {
        return this.api.apiConsumerProjectLocalGetPeriodDates(param.companyId, param.acceptEncoding,  options).toPromise();
    }

}
