import { ResponseContext, RequestContext, HttpFile } from '../http/http';
import { Configuration} from '../configuration'
import { Observable, of, from } from '../rxjsStub';
import {mergeMap, map} from  '../rxjsStub';
import { CommentRefsInner } from '../models/CommentRefsInner';
import { CompanyDatapointResponse } from '../models/CompanyDatapointResponse';
import { CompanyDatapointResponseData } from '../models/CompanyDatapointResponseData';
import { CompanyDescriptionResponse } from '../models/CompanyDescriptionResponse';
import { CompanyDescriptionResponseMeta } from '../models/CompanyDescriptionResponseMeta';
import { CompanyFinancialsResponse } from '../models/CompanyFinancialsResponse';
import { CompanyFinancialsResponseData } from '../models/CompanyFinancialsResponseData';
import { CompanyPeriodDatesResponse } from '../models/CompanyPeriodDatesResponse';
import { CompanyPeriodDatesResponseData } from '../models/CompanyPeriodDatesResponseData';
import { CompanyTimeSeriesResponse } from '../models/CompanyTimeSeriesResponse';
import { CompanyTimeSeriesResponseData } from '../models/CompanyTimeSeriesResponseData';
import { ComparablesInner } from '../models/ComparablesInner';
import { ComparablesResponse } from '../models/ComparablesResponse';
import { DataInner } from '../models/DataInner';
import { DataInner1 } from '../models/DataInner1';
import { DataInner2 } from '../models/DataInner2';
import { FinancialsInner } from '../models/FinancialsInner';
import { Multiplier } from '../models/Multiplier';
import { PartsInner } from '../models/PartsInner';
import { PeriodDatesInner } from '../models/PeriodDatesInner';
import { TimeSeriesInner } from '../models/TimeSeriesInner';

import { DefaultApiRequestFactory, DefaultApiResponseProcessor} from "../apis/DefaultApi";
export class ObservableDefaultApi {
    private requestFactory: DefaultApiRequestFactory;
    private responseProcessor: DefaultApiResponseProcessor;
    private configuration: Configuration;

    public constructor(
        configuration: Configuration,
        requestFactory?: DefaultApiRequestFactory,
        responseProcessor?: DefaultApiResponseProcessor
    ) {
        this.configuration = configuration;
        this.requestFactory = requestFactory || new DefaultApiRequestFactory(configuration);
        this.responseProcessor = responseProcessor || new DefaultApiResponseProcessor();
    }

    /**
     * Returns comparables data for a list of companies for the allowed coverage_universe
     * Get company comparables
     * @param interval identifier for the interval of comparables data to fetch
     * @param atTimestamp ISO-8601 Timestamp to return comparables snapshot for
     * @param companyIds filter by supplied company ids
     * @param limit maximum number of results to return - typically used when paging
     * @param continuationToken identifier of last result in previous result set - allows continuation of paged results
     * @param acceptEncoding client supported encodings (gzip, deflate, br)
     */
    public apiConsumerProjectLocalGetCompanyComparablesSubtypes(interval: string, atTimestamp?: Date, companyIds?: string, limit?: number, continuationToken?: string, acceptEncoding?: string, _options?: Configuration): Observable<ComparablesResponse> {
        const requestContextPromise = this.requestFactory.apiConsumerProjectLocalGetCompanyComparablesSubtypes(interval, atTimestamp, companyIds, limit, continuationToken, acceptEncoding, _options);

        // build promise chain
        let middlewarePreObservable = from<RequestContext>(requestContextPromise);
        for (let middleware of this.configuration.middleware) {
            middlewarePreObservable = middlewarePreObservable.pipe(mergeMap((ctx: RequestContext) => middleware.pre(ctx)));
        }

        return middlewarePreObservable.pipe(mergeMap((ctx: RequestContext) => this.configuration.httpApi.send(ctx))).
            pipe(mergeMap((response: ResponseContext) => {
                let middlewarePostObservable = of(response);
                for (let middleware of this.configuration.middleware) {
                    middlewarePostObservable = middlewarePostObservable.pipe(mergeMap((rsp: ResponseContext) => middleware.post(rsp)));
                }
                return middlewarePostObservable.pipe(map((rsp: ResponseContext) => this.responseProcessor.apiConsumerProjectLocalGetCompanyComparablesSubtypes(rsp)));
            }));
    }

    /**
     * Returns details of an individual datapoint for a company
     * Get a company datapoint
     * @param datapointId identifier for the datapoint
     * @param acceptEncoding client supported encodings (gzip, deflate, br)
     */
    public apiConsumerProjectLocalGetCompanyDatapoint(datapointId: string, acceptEncoding?: string, _options?: Configuration): Observable<CompanyDatapointResponse> {
        const requestContextPromise = this.requestFactory.apiConsumerProjectLocalGetCompanyDatapoint(datapointId, acceptEncoding, _options);

        // build promise chain
        let middlewarePreObservable = from<RequestContext>(requestContextPromise);
        for (let middleware of this.configuration.middleware) {
            middlewarePreObservable = middlewarePreObservable.pipe(mergeMap((ctx: RequestContext) => middleware.pre(ctx)));
        }

        return middlewarePreObservable.pipe(mergeMap((ctx: RequestContext) => this.configuration.httpApi.send(ctx))).
            pipe(mergeMap((response: ResponseContext) => {
                let middlewarePostObservable = of(response);
                for (let middleware of this.configuration.middleware) {
                    middlewarePostObservable = middlewarePostObservable.pipe(mergeMap((rsp: ResponseContext) => middleware.post(rsp)));
                }
                return middlewarePostObservable.pipe(map((rsp: ResponseContext) => this.responseProcessor.apiConsumerProjectLocalGetCompanyDatapoint(rsp)));
            }));
    }

    /**
     * Returns historical financials data for single company
     * Get company financials
     * @param companyId identifier for the company to fetch financials for
     * @param atTimestamp ISO-8601 Timestamp to return financials snapshot for
     * @param acceptEncoding client supported encodings (gzip, deflate, br)
     */
    public apiConsumerProjectLocalGetCompanyFinancials(companyId: string, atTimestamp?: Date, acceptEncoding?: string, _options?: Configuration): Observable<CompanyFinancialsResponse> {
        const requestContextPromise = this.requestFactory.apiConsumerProjectLocalGetCompanyFinancials(companyId, atTimestamp, acceptEncoding, _options);

        // build promise chain
        let middlewarePreObservable = from<RequestContext>(requestContextPromise);
        for (let middleware of this.configuration.middleware) {
            middlewarePreObservable = middlewarePreObservable.pipe(mergeMap((ctx: RequestContext) => middleware.pre(ctx)));
        }

        return middlewarePreObservable.pipe(mergeMap((ctx: RequestContext) => this.configuration.httpApi.send(ctx))).
            pipe(mergeMap((response: ResponseContext) => {
                let middlewarePostObservable = of(response);
                for (let middleware of this.configuration.middleware) {
                    middlewarePostObservable = middlewarePostObservable.pipe(mergeMap((rsp: ResponseContext) => middleware.post(rsp)));
                }
                return middlewarePostObservable.pipe(map((rsp: ResponseContext) => this.responseProcessor.apiConsumerProjectLocalGetCompanyFinancials(rsp)));
            }));
    }

    /**
     * Returns a list of company description objects.
     * Get company descriptions
     * @param atTimestamp ISO-8601 Timestamp to return companies snapshot for
     * @param isRetired filter by \&#39;retired\&#39; status - (true|false)
     * @param companyIds filter by supplied company ids - comma separated list
     * @param tickers filter by supplied company tickers
     * @param limit maximum number of results to return - typically used when paging
     * @param updatedAfter Only return company descriptions added or updated on or after this ISO-8601 timestamp
     * @param updatedBefore Only return company descriptions added or updated before this ISO-8601 timestamp
     * @param lastReportedDateAfter Only return company descriptions for companies with reports on or after this ISO-8601 timestamp
     * @param lastReportedDateBefore Only return company descriptions for companies with reports before this ISO-8601 timestamp
     * @param continuationToken identifier of last result in previous result set - allows continuation of paged results
     * @param acceptEncoding client supported encodings (gzip, deflate, br)
     */
    public apiConsumerProjectLocalGetCompanyListings(atTimestamp?: Date, isRetired?: string, companyIds?: string, tickers?: string, limit?: number, updatedAfter?: Date, updatedBefore?: Date, lastReportedDateAfter?: Date, lastReportedDateBefore?: Date, continuationToken?: string, acceptEncoding?: string, _options?: Configuration): Observable<CompanyDescriptionResponse> {
        const requestContextPromise = this.requestFactory.apiConsumerProjectLocalGetCompanyListings(atTimestamp, isRetired, companyIds, tickers, limit, updatedAfter, updatedBefore, lastReportedDateAfter, lastReportedDateBefore, continuationToken, acceptEncoding, _options);

        // build promise chain
        let middlewarePreObservable = from<RequestContext>(requestContextPromise);
        for (let middleware of this.configuration.middleware) {
            middlewarePreObservable = middlewarePreObservable.pipe(mergeMap((ctx: RequestContext) => middleware.pre(ctx)));
        }

        return middlewarePreObservable.pipe(mergeMap((ctx: RequestContext) => this.configuration.httpApi.send(ctx))).
            pipe(mergeMap((response: ResponseContext) => {
                let middlewarePostObservable = of(response);
                for (let middleware of this.configuration.middleware) {
                    middlewarePostObservable = middlewarePostObservable.pipe(mergeMap((rsp: ResponseContext) => middleware.post(rsp)));
                }
                return middlewarePostObservable.pipe(map((rsp: ResponseContext) => this.responseProcessor.apiConsumerProjectLocalGetCompanyListings(rsp)));
            }));
    }

    /**
     * Returns all historical values of a specific comparable for a given company and interval
     * Get company time series
     * @param companyId identifier for the company to fetch time series data for
     * @param tag identifier for the comparable tag to fetch time series data for
     * @param interval identifier for the interval to fetch time series data for
     * @param acceptEncoding client supported encodings (gzip, deflate, br)
     */
    public apiConsumerProjectLocalGetCompanyTimeSeries(companyId: string, tag: string, interval: string, acceptEncoding?: string, _options?: Configuration): Observable<CompanyTimeSeriesResponse> {
        const requestContextPromise = this.requestFactory.apiConsumerProjectLocalGetCompanyTimeSeries(companyId, tag, interval, acceptEncoding, _options);

        // build promise chain
        let middlewarePreObservable = from<RequestContext>(requestContextPromise);
        for (let middleware of this.configuration.middleware) {
            middlewarePreObservable = middlewarePreObservable.pipe(mergeMap((ctx: RequestContext) => middleware.pre(ctx)));
        }

        return middlewarePreObservable.pipe(mergeMap((ctx: RequestContext) => this.configuration.httpApi.send(ctx))).
            pipe(mergeMap((response: ResponseContext) => {
                let middlewarePostObservable = of(response);
                for (let middleware of this.configuration.middleware) {
                    middlewarePostObservable = middlewarePostObservable.pipe(mergeMap((rsp: ResponseContext) => middleware.post(rsp)));
                }
                return middlewarePostObservable.pipe(map((rsp: ResponseContext) => this.responseProcessor.apiConsumerProjectLocalGetCompanyTimeSeries(rsp)));
            }));
    }

    /**
     * Returns comparables data for a list of companies for the allowed coverage_universe, from a given start timestamp and optional end timestamp
     * Get company comparables updates for a given time period
     * @param startTimestamp ISO-8601 Timestamp to return comparables updates since (all updates greater than or equal to the timestamp)
     * @param endTimestamp ISO-8601 Timestamp to return comparables updates until (all updates less than, but not equal to, the timestamp)
     * @param companyIds filter by supplied company ids
     * @param limit maximum number of results to return - typically used when paging
     * @param continuationToken identifier of last result in previous result set - allows continuation of paged results
     * @param acceptEncoding client supported encodings (gzip, deflate, br)
     */
    public apiConsumerProjectLocalGetComparablesUpdatesSince(startTimestamp?: Date, endTimestamp?: Date, companyIds?: string, limit?: number, continuationToken?: string, acceptEncoding?: string, _options?: Configuration): Observable<ComparablesResponse> {
        const requestContextPromise = this.requestFactory.apiConsumerProjectLocalGetComparablesUpdatesSince(startTimestamp, endTimestamp, companyIds, limit, continuationToken, acceptEncoding, _options);

        // build promise chain
        let middlewarePreObservable = from<RequestContext>(requestContextPromise);
        for (let middleware of this.configuration.middleware) {
            middlewarePreObservable = middlewarePreObservable.pipe(mergeMap((ctx: RequestContext) => middleware.pre(ctx)));
        }

        return middlewarePreObservable.pipe(mergeMap((ctx: RequestContext) => this.configuration.httpApi.send(ctx))).
            pipe(mergeMap((response: ResponseContext) => {
                let middlewarePostObservable = of(response);
                for (let middleware of this.configuration.middleware) {
                    middlewarePostObservable = middlewarePostObservable.pipe(mergeMap((rsp: ResponseContext) => middleware.post(rsp)));
                }
                return middlewarePostObservable.pipe(map((rsp: ResponseContext) => this.responseProcessor.apiConsumerProjectLocalGetComparablesUpdatesSince(rsp)));
            }));
    }

    /**
     * Returns end dates of financial reporting periods for given company
     * Get company period dates
     * @param companyId identifier for the company to fetch financials for
     * @param acceptEncoding client supported encodings (gzip, deflate, br)
     */
    public apiConsumerProjectLocalGetPeriodDates(companyId: string, acceptEncoding?: string, _options?: Configuration): Observable<CompanyPeriodDatesResponse> {
        const requestContextPromise = this.requestFactory.apiConsumerProjectLocalGetPeriodDates(companyId, acceptEncoding, _options);

        // build promise chain
        let middlewarePreObservable = from<RequestContext>(requestContextPromise);
        for (let middleware of this.configuration.middleware) {
            middlewarePreObservable = middlewarePreObservable.pipe(mergeMap((ctx: RequestContext) => middleware.pre(ctx)));
        }

        return middlewarePreObservable.pipe(mergeMap((ctx: RequestContext) => this.configuration.httpApi.send(ctx))).
            pipe(mergeMap((response: ResponseContext) => {
                let middlewarePostObservable = of(response);
                for (let middleware of this.configuration.middleware) {
                    middlewarePostObservable = middlewarePostObservable.pipe(mergeMap((rsp: ResponseContext) => middleware.post(rsp)));
                }
                return middlewarePostObservable.pipe(map((rsp: ResponseContext) => this.responseProcessor.apiConsumerProjectLocalGetPeriodDates(rsp)));
            }));
    }

}
