import { ResponseContext, RequestContext, HttpFile } from '../http/http';
import { Configuration} from '../configuration'

import { CommentRefsInner } from '../models/CommentRefsInner';
import { CompanyDatapointResponse } from '../models/CompanyDatapointResponse';
import { CompanyDatapointResponseData } from '../models/CompanyDatapointResponseData';
import { CompanyDescriptionResponse } from '../models/CompanyDescriptionResponse';
import { CompanyDescriptionResponseMeta } from '../models/CompanyDescriptionResponseMeta';
import { CompanyFinancialsResponse } from '../models/CompanyFinancialsResponse';
import { CompanyFinancialsResponseData } from '../models/CompanyFinancialsResponseData';
import { CompanyPeriodDatesResponse } from '../models/CompanyPeriodDatesResponse';
import { CompanyPeriodDatesResponseData } from '../models/CompanyPeriodDatesResponseData';
import { CompanyTimeSeriesResponse } from '../models/CompanyTimeSeriesResponse';
import { CompanyTimeSeriesResponseData } from '../models/CompanyTimeSeriesResponseData';
import { ComparablesInner } from '../models/ComparablesInner';
import { ComparablesResponse } from '../models/ComparablesResponse';
import { DataInner } from '../models/DataInner';
import { DataInner1 } from '../models/DataInner1';
import { DataInner2 } from '../models/DataInner2';
import { FinancialsInner } from '../models/FinancialsInner';
import { Multiplier } from '../models/Multiplier';
import { PartsInner } from '../models/PartsInner';
import { PeriodDatesInner } from '../models/PeriodDatesInner';
import { TimeSeriesInner } from '../models/TimeSeriesInner';
import { ObservableDefaultApi } from './ObservableAPI';

import { DefaultApiRequestFactory, DefaultApiResponseProcessor} from "../apis/DefaultApi";
export class PromiseDefaultApi {
    private api: ObservableDefaultApi

    public constructor(
        configuration: Configuration,
        requestFactory?: DefaultApiRequestFactory,
        responseProcessor?: DefaultApiResponseProcessor
    ) {
        this.api = new ObservableDefaultApi(configuration, requestFactory, responseProcessor);
    }

    /**
     * Returns comparables data for a list of companies for the allowed coverage_universe
     * Get company comparables
     * @param interval identifier for the interval of comparables data to fetch
     * @param atTimestamp ISO-8601 Timestamp to return comparables snapshot for
     * @param companyIds filter by supplied company ids
     * @param limit maximum number of results to return - typically used when paging
     * @param continuationToken identifier of last result in previous result set - allows continuation of paged results
     * @param acceptEncoding client supported encodings (gzip, deflate, br)
     */
    public apiConsumerProjectLocalGetCompanyComparablesSubtypes(interval: string, atTimestamp?: Date, companyIds?: string, limit?: number, continuationToken?: string, acceptEncoding?: string, _options?: Configuration): Promise<ComparablesResponse> {
        const result = this.api.apiConsumerProjectLocalGetCompanyComparablesSubtypes(interval, atTimestamp, companyIds, limit, continuationToken, acceptEncoding, _options);
        return result.toPromise();
    }

    /**
     * Returns details of an individual datapoint for a company
     * Get a company datapoint
     * @param datapointId identifier for the datapoint
     * @param acceptEncoding client supported encodings (gzip, deflate, br)
     */
    public apiConsumerProjectLocalGetCompanyDatapoint(datapointId: string, acceptEncoding?: string, _options?: Configuration): Promise<CompanyDatapointResponse> {
        const result = this.api.apiConsumerProjectLocalGetCompanyDatapoint(datapointId, acceptEncoding, _options);
        return result.toPromise();
    }

    /**
     * Returns historical financials data for single company
     * Get company financials
     * @param companyId identifier for the company to fetch financials for
     * @param atTimestamp ISO-8601 Timestamp to return financials snapshot for
     * @param acceptEncoding client supported encodings (gzip, deflate, br)
     */
    public apiConsumerProjectLocalGetCompanyFinancials(companyId: string, atTimestamp?: Date, acceptEncoding?: string, _options?: Configuration): Promise<CompanyFinancialsResponse> {
        const result = this.api.apiConsumerProjectLocalGetCompanyFinancials(companyId, atTimestamp, acceptEncoding, _options);
        return result.toPromise();
    }

    /**
     * Returns a list of company description objects.
     * Get company descriptions
     * @param atTimestamp ISO-8601 Timestamp to return companies snapshot for
     * @param isRetired filter by \&#39;retired\&#39; status - (true|false)
     * @param companyIds filter by supplied company ids - comma separated list
     * @param tickers filter by supplied company tickers
     * @param limit maximum number of results to return - typically used when paging
     * @param updatedAfter Only return company descriptions added or updated on or after this ISO-8601 timestamp
     * @param updatedBefore Only return company descriptions added or updated before this ISO-8601 timestamp
     * @param lastReportedDateAfter Only return company descriptions for companies with reports on or after this ISO-8601 timestamp
     * @param lastReportedDateBefore Only return company descriptions for companies with reports before this ISO-8601 timestamp
     * @param continuationToken identifier of last result in previous result set - allows continuation of paged results
     * @param acceptEncoding client supported encodings (gzip, deflate, br)
     */
    public apiConsumerProjectLocalGetCompanyListings(atTimestamp?: Date, isRetired?: string, companyIds?: string, tickers?: string, limit?: number, updatedAfter?: Date, updatedBefore?: Date, lastReportedDateAfter?: Date, lastReportedDateBefore?: Date, continuationToken?: string, acceptEncoding?: string, _options?: Configuration): Promise<CompanyDescriptionResponse> {
        const result = this.api.apiConsumerProjectLocalGetCompanyListings(atTimestamp, isRetired, companyIds, tickers, limit, updatedAfter, updatedBefore, lastReportedDateAfter, lastReportedDateBefore, continuationToken, acceptEncoding, _options);
        return result.toPromise();
    }

    /**
     * Returns all historical values of a specific comparable for a given company and interval
     * Get company time series
     * @param companyId identifier for the company to fetch time series data for
     * @param tag identifier for the comparable tag to fetch time series data for
     * @param interval identifier for the interval to fetch time series data for
     * @param acceptEncoding client supported encodings (gzip, deflate, br)
     */
    public apiConsumerProjectLocalGetCompanyTimeSeries(companyId: string, tag: string, interval: string, acceptEncoding?: string, _options?: Configuration): Promise<CompanyTimeSeriesResponse> {
        const result = this.api.apiConsumerProjectLocalGetCompanyTimeSeries(companyId, tag, interval, acceptEncoding, _options);
        return result.toPromise();
    }

    /**
     * Returns comparables data for a list of companies for the allowed coverage_universe, from a given start timestamp and optional end timestamp
     * Get company comparables updates for a given time period
     * @param startTimestamp ISO-8601 Timestamp to return comparables updates since (all updates greater than or equal to the timestamp)
     * @param endTimestamp ISO-8601 Timestamp to return comparables updates until (all updates less than, but not equal to, the timestamp)
     * @param companyIds filter by supplied company ids
     * @param limit maximum number of results to return - typically used when paging
     * @param continuationToken identifier of last result in previous result set - allows continuation of paged results
     * @param acceptEncoding client supported encodings (gzip, deflate, br)
     */
    public apiConsumerProjectLocalGetComparablesUpdatesSince(startTimestamp?: Date, endTimestamp?: Date, companyIds?: string, limit?: number, continuationToken?: string, acceptEncoding?: string, _options?: Configuration): Promise<ComparablesResponse> {
        const result = this.api.apiConsumerProjectLocalGetComparablesUpdatesSince(startTimestamp, endTimestamp, companyIds, limit, continuationToken, acceptEncoding, _options);
        return result.toPromise();
    }

    /**
     * Returns end dates of financial reporting periods for given company
     * Get company period dates
     * @param companyId identifier for the company to fetch financials for
     * @param acceptEncoding client supported encodings (gzip, deflate, br)
     */
    public apiConsumerProjectLocalGetPeriodDates(companyId: string, acceptEncoding?: string, _options?: Configuration): Promise<CompanyPeriodDatesResponse> {
        const result = this.api.apiConsumerProjectLocalGetPeriodDates(companyId, acceptEncoding, _options);
        return result.toPromise();
    }


}



